From 4e370920959483580fb1a2cd452ed2fe6db4c10f Mon Sep 17 00:00:00 2001
From: Ben Pfaff <blp@gnu.org>
Date: Mon, 26 Jun 2006 05:25:17 +0000
Subject: [PATCH] Fix comment.

---
 src/libpspp/hash.c | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/src/libpspp/hash.c b/src/libpspp/hash.c
index c3a7eb7e..55b3a6f1 100644
--- a/src/libpspp/hash.c
+++ b/src/libpspp/hash.c
@@ -231,8 +231,9 @@ hsh_destroy (struct hsh_table *h)
     }
 }
 
-/* Locates an entry matching TARGET.  Returns a pointer to the
-   entry, or a null pointer on failure. */
+/* Locates an entry matching TARGET.  Returns the index for the
+   entry, if found, or the index of an empty entry that indicates
+   where TARGET should go, otherwise. */
 static inline unsigned
 locate_matching_entry (struct hsh_table *h, const void *target) 
 {
-- 
2.30.2